@@ -423,7 +423,7 @@ makeServletInternal cgigen (CGI cgi) = \ info decoded_parameters ->
 	   -- this request. However, we cannot terminate at this time because
 	   -- exiting will close the output handle for the other thread!
      unless b $ do
-       if null args
+       if null args || null (head args)
 	 then cgi cgistate >> return ()
 	 else unCGI (cgigen $ args) cgistate >> return ()
        exitWith ExitSuccess
