@@ -387,6 +387,7 @@ genericField inputType decode fieldAttrs =
 		 unless (isFILE || isSUBMIT) $ case maybestring of 
 	           Nothing -> H.empty
 		   Just str -> H.attr_SD "value" str
+		 H.attr_SS "title" explanation
 		 return (explanation,
 		   InputField { ifName = nameAttr
 			      , ifToken = fieldName''
@@ -555,7 +556,13 @@ constructQuery url args =
 -- |Wraps an HTML form around its arguments. All standard attributes are
 -- computed and need not be supplied explicitly.
 makeForm :: (CGIMonad cgi) => H.WithHTML x cgi a -> H.WithHTML y cgi ()
-makeForm attrs_elems = do
+makeForm attrs_elems = 
+  makeFormWithErrorMark
+    -- ["style.backgroundColor='red'", "style.borderColor='black'"]
+    ["className='faultyinput'"]
+    attrs_elems
+
+makeFormWithErrorMark errorMarks attrs_elems = do
   url <- H.lift getUrl
   args <- H.lift getCGIArgs
   js_enabled <- H.lift getJSEnabled
@@ -632,8 +639,8 @@ makeForm attrs_elems = do
 	     "if(document.i" ++ fname ++ ")" ++
 	     "document.i" ++ fname ++ ".src = " ++ jsShow questionURL ++ ";" ++
 	     "else{" ++
-	     "document.forms[0]." ++ fname ++ ".style.backgroundColor='red';" ++
-	     "document.forms[0]." ++ fname ++ ".style.borderColor='black';" ++
+	     (let f mark = "document.forms[0]." ++ fname ++ "." ++ mark ++ ";" in
+	     List.concatMap f errorMarks) ++
 	     "}"
 	    | otherwise =
 	     "popupstr += " 
