@@ -22,10 +22,10 @@ urlEncode xs =
   urlEncode' xs ""
 urlEncode' "" = id
 urlEncode' (x:xs) = 
-  if isAlphaNum x 
+  (if isAlphaNum x 
   then showChar x
   else showChar '%' .
-       showsHex 2 (ord x)
+       showsHex 2 (ord x)) . urlEncode' xs
 
 urlDecode :: String -> String
 urlDecode "" = ""
